OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "New note" : "Nova nota",
    "Note is currently saving. Leaving the page will delete all changes!" : "A anotação está sendo salva. Sair da página irá apagar todas as mudanças!",
    "_%n word_::_%n words_" : ["%n palavra","%n palavras"],
    "Delete note" : "Excluir anotação",
    "Favorite" : "Favorito",
    "No notes found" : "Nenhuma nota encontrada"
},
"nplurals=2; plural=(n > 1);");
